Bootstrap Switch · Turn checkboxes and radio buttons into toggle switches
Author: Mattia Larentis, Emanuele Marchi and Peter Stein
Description: Turn checkboxes and radio buttons into toggle switches

# Bootstrap Switch

Turn checkboxes and radio buttons into toggle switches

Download Bootstrap Switch

Currently v3.3.4 · Compatible with Bootstrap 2 and 3

## Getting Started

Include the dependencies: jQuery, Bootstrap and Bootstrap Switch CSS + Javascript.

    [...]
    <link href="bootstrap.css" rel="stylesheet">
    <link href="bootstrap-switch.css" rel="stylesheet">
    <script src="jquery.js"></script>
    <script src="bootstrap-switch.js"></script>
    [...]

Add your checkbox.

    <input type="checkbox" name="my-checkbox" checked>

Initialize Bootstrap Switch.

    $("[name='my-checkbox']").bootstrapSwitch();

Enjoy.

See Examples Browse Documentation